@@ -27,13 +27,19 @@ CSE_CX_Table = Table(
 class CSECreate(BaseModel):
   name: str
   description: str
+  cxes: List[int]
+  domains: List[int]
 
 class CSEUpdate(BaseModel):
   name: str
   description: str
+  cxes: List[int]
+  domains: List[int]
 
-class CSE(CSECreate):
+class CSE(BaseModel):
   id: int
+  name: str
+  description: str
   cxes: List[CSECX] = []
   domains: List[Domain] = []
   class Config:
